summaryrefslogtreecommitdiffstats
path: root/chromium/content/renderer/notification_provider.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/content/renderer/notification_provider.h')
-rw-r--r--chromium/content/renderer/notification_provider.h15
1 files changed, 7 insertions, 8 deletions
diff --git a/chromium/content/renderer/notification_provider.h b/chromium/content/renderer/notification_provider.h
index 8abafb1caf7..5162c14426e 100644
--- a/chromium/content/renderer/notification_provider.h
+++ b/chromium/content/renderer/notification_provider.h
@@ -5,7 +5,7 @@
#ifndef CONTENT_RENDERER_NOTIFICATION_PROVIDER_H_
#define CONTENT_RENDERER_NOTIFICATION_PROVIDER_H_
-#include "content/public/renderer/render_view_observer.h"
+#include "content/public/renderer/render_frame_observer.h"
#include "content/renderer/active_notification_tracker.h"
#include "third_party/WebKit/public/web/WebNotification.h"
#include "third_party/WebKit/public/web/WebNotificationPresenter.h"
@@ -15,18 +15,17 @@ class WebNotificationPermissionCallback;
}
namespace content {
-class RenderViewImpl;
-// NotificationProvider class is owned by the RenderView. Only
-// to be used on the main thread.
-class NotificationProvider : public RenderViewObserver,
+// NotificationProvider class is owned by the RenderFrame. Only to be used on
+// the main thread.
+class NotificationProvider : public RenderFrameObserver,
public blink::WebNotificationPresenter {
public:
- explicit NotificationProvider(RenderViewImpl* render_view);
+ explicit NotificationProvider(RenderFrame* render_frame);
virtual ~NotificationProvider();
private:
- // RenderView::Observer implementation.
+ // RenderFrameObserver implementation.
virtual bool OnMessageReceived(const IPC::Message& message) OVERRIDE;
// blink::WebNotificationPresenter interface.
@@ -40,7 +39,7 @@ class NotificationProvider : public RenderViewObserver,
// IPC handlers.
void OnDisplay(int id);
- void OnError(int id, const blink::WebString& message);
+ void OnError(int id);
void OnClose(int id, bool by_user);
void OnClick(int id);
void OnPermissionRequestComplete(int id);